summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kaccountsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kaccountsview.h')
-rw-r--r--kmymoney2/views/kaccountsview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/views/kaccountsview.h b/kmymoney2/views/kaccountsview.h
index 96c547a..892af17 100644
--- a/kmymoney2/views/kaccountsview.h
+++ b/kmymoney2/views/kaccountsview.h
@@ -43,16 +43,16 @@ class TDEListViewSearchLineWidget;
* This class represents an item in the account icon view. It is used
* by the KAccountsView to select between the accounts using icons.
*/
-class KMyMoneyAccountIconItem : public KIconViewItem
+class KMyMoneyAccountIconItem : public TDEIconViewItem
{
public:
/**
* Constructor to be used to construct an account icon object.
*
* @param parent pointer to the KIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KIconView entry is constructed
*/
KMyMoneyAccountIconItem(TQIconView *parent, const MyMoneyAccount& account);
~KMyMoneyAccountIconItem();
@@ -43,16 +43,16 @@ class TDEListViewSearchLineWidget;
* Constructor to be used to construct an account icon object.
*
- * @param parent pointer to the KIconView object this entry should be
+ * @param parent pointer to the TDEIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -43,16 +43,16 @@ class TDEListViewSearchLineWidget;
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KIconView entry is constructed
+ * the TDEIconView entry is constructed
*/
KMyMoneyAccountIconItem(TQIconView *parent, const MyMoneyAccount& account);